.. Copyright (C) 2017 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

.. _ansible_roles:

Roles (index)
=============

.. toctree::
   :maxdepth: 1
   :glob:

   */index

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
